"""Dictionary mapping Unicode codepoints with accents to
codepoint with accent stripped.

We can't just use Unicode.normalize with stripmark flag because
that strips breathings, iota subscripts, and diaereses as well.
"""
function accentdict() 
    Dict(
       'ά'  => 'α',
       'ὰ' => 'α',
       'ᾶ' => 'α',
       'ᾴ' => 'ᾳ',
       'ᾲ' => 'ᾳ',
       'ᾷ' => 'ᾳ',
       'ἄ' => 'ἀ',
       'ἂ' => 'ἀ',
       'ἆ' => 'ἀ',
       'ᾄ' => 'ᾀ',
       'ᾂ' => 'ᾀ',
       'ᾆ' => 'ᾀ',
       'ἅ' => 'ἁ',
       'ἃ' => 'ἁ',
       'ἇ' => 'ἁ',
       'ᾅ' => 'ᾁ',
       'ᾃ' => 'ᾁ',
       'ᾇ' => 'ᾁ',
       #= eta goes like alpha =#
       'ή'  => 'η',
       'ὴ' => 'η',
       'ῆ' => 'η',
       'ῄ' => 'ῃ',
       'ῂ' => 'ῃ',
       'ῇ' => 'ῃ',
       'ἤ' => 'ἠ',
       'ἢ' => 'ἠ',
       'ἦ' => 'ἠ',
       'ᾔ' => 'ᾐ',
       'ᾒ' => 'ᾐ',
       'ᾖ' => 'ᾐ',
       'ἥ' => 'ἡ',
       'ἣ' => 'ἡ',
       'ἧ' => 'ἡ',
       'ᾕ' => 'ᾑ',
       'ᾓ' => 'ᾑ',
       'ᾗ' => 'ᾑ',
       #= omega goes like eta and alpha =#
       'ώ'  => 'ω',
       'ὼ' => 'ω',
       'ῶ' => 'ω',
       'ῴ' => 'ῳ',
       'ῲ' => 'ῳ',
       'ῷ' => 'ῳ',
       'ὤ' => 'ὠ',
       'ὢ' => 'ὠ',
       'ὦ' => 'ὠ',
       'ᾤ' => 'ᾠ',
       'ᾢ' => 'ᾠ',
       'ᾦ' => 'ᾠ',
       'ὥ' => 'ὡ',
       'ὣ' => 'ὡ',
       'ὧ' => 'ὡ',
       'ᾥ' => 'ᾡ',
       'ᾓ' => 'ᾡ',
       'ᾗ' => 'ᾡ',
       #= iota is different =#
       'ί' => 'ι',
       'ὶ' => 'ι',
       'ῖ' => 'ι',
       'ἴ' => 'ἰ',
       'ἲ' => 'ἰ',
       'ἶ' => 'ἱ',
       'ἵ' => 'ἱ',
       'ἳ' => 'ἱ',
       'ἷ' => 'ἱ',
       'ΐ' => 'ϊ',
       'ῒ' => 'ϊ',
       'ῗ' => 'ϊ',
       #= upsilon goes like iota =#
       'ύ' => 'υ',
       'ὺ' => 'υ',
       'ῦ' => 'υ',
       'ὔ' => 'ὐ',
       'ὒ' => 'ὐ',
       'ὖ' => 'ὐ',
       'ὕ' => 'ὑ',
       'ὓ' => 'ὑ',
       'ὗ' => 'ὑ',
       'ΰ' => 'ϋ',
       'ῢ' => 'ϋ',
       'ῧ' => 'ϋ',
       'έ' => 'ε',
       'ὲ' => 'ε',
       'ἔ' => 'ἐ',
       'ἒ' => 'ἐ',
       'ἕ' => 'ἐ',
       'ἓ' => 'ἑ',
       'ό' => 'ο',
       'ὸ' => 'ο',
       'ὄ' => 'ὀ',
       'ὂ' => 'ὀ',
       'ὅ' => 'ὁ',
       'ὃ' => 'ὁ'
   )
end